@@ -14,7 +14,7 @@ class Command(BaseCommand):
     """
     option_list = BaseCommand.option_list + (
         make_option('--app-label',dest='app_label',help='The app label to which the local model belongs.'),
-        make_option('--local-type',dest='local_type',help='The name of the local model'),
+        make_option('--local-model',dest='local_model',help='The name of the local model'),
         make_option('--local-id',dest='local_id',help='The id of the local model'),
         make_option('--content-key',dest='content_key',help='The ACE content key to associate.'),
     )
@@ -25,13 +25,13 @@ class Command(BaseCommand):
         """
         content_type = None
         try:
-            content_type = ContentType.objects.get(app_label=options['app_label'],local_type=options['local_type'])
+            content_type = ContentType.objects.get(app_label=options['app_label'],model=options['local_model'])
         except ContentType.DoesNotExist:
             raise CommandError('No such local content type.')
         
         local_model = content_type.model_class()
         if not hasattr(local_model,'ACE'):
-            raise CommandError('Local model %s is not configured to be linked to ACE.' % options['local_type'])
+            raise CommandError('Local model %s is not configured to be linked to ACE.' % options['local_model'])
         
         AxilentContentRecord.objects.create(local_content_type=content_type,
                                             local_id=int(options['local_id']),
